(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 2000 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* Extra graphics functions primitives. *)
open Graphics;;

type pixels = color array array;;

val draw_pixels : int array array -> int -> int -> unit;;
 (* [draw_pixels pixels x y] draw the given color matrix
    with lower left corner at the given point. *) 

val color_of_rgb : int -> int -> int -> color;;
 (* [color_of_rgb r g b] returns the integer encoding the color with red
    component [r], green component [g], and blue component
   [b]. *)

val r_of_color : color -> int;;
val g_of_color : color -> int;;
val b_of_color : color -> int;;
val rgb_of_color : color -> int * int * int;;
 (* Decomposition of a color into its red, green, blue components. *)

val hsb_of_color : color -> int * int * int;;
 (* Decomposition of a color specified by its H (hue), S (saturation),
    and B (brightness) components. Hue is the wavelength within the
    visible-light spectrum at which the energy output from a source of
    this color is greatest. Sauration measures the purity of colors:
    high saturation means a pure color, low saturation means a faint color.
    Brightness (also called brilliance) is the maximum of the RGB
    components of the color.
 *)
val hsb_of_rgb : int -> int -> int -> (int * int * int);;
val rgb_of_hsb : int -> int -> int -> int * int * int;;
 (* Mappings from HSB to RGB representations of colors. [hsb_of_rgb]
    and [rgb_of_hsb] are not strictly reciprocal, due to limit
    conditions, where some components are undefined and arbitrarily
    set to 0. *)

val bitmap_of_pixels : ts:int -> tb:int -> pixels -> pixels;;
 (* [bitmap_of_pixels ts tb pixels] Maps a matrix of colors into a
    bitmap represented as a new matrix of black or white
    colors. Arguments [ts] and [tb] are tresholds to decide whether to
    produce a black or white pixel from a pixel of a given color: both
    [ts] and [tb] are integers in the range [0 .. 255]; [ts] is the
    saturation threshold and if the saturation of the pixel color is
    greater than [ts] then the pixel is assumed to be [white]; [tb] is
    the brightness threshold and if the brightness of the pixel color
    is greater than [ts] then the pixel is assumed to be [white]. The
    correct values of [ts] and [tb] highly depend on the image at
    hand, but [ts = 20] and [tb = 210] often give good results. *)

